@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmPcap.cc 9479 2017-06-08 16:03:43Z dwm $
+// @(#) $Id: DwmPcap.cc 9530 2017-06-14 17:24:33Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007, 2016
 //  All rights reserved.
@@ -39,6 +39,16 @@
 //!  \brief Pcap class implementation
 //---------------------------------------------------------------------------
 
+#include "DwmPortability.hh"
+
+extern "C" {
+#if (defined(HAVE_NET_PFVAR_H) && defined(HAVE_NET_IF_PFLOG_H))
+  #include <net/if.h>
+  #include <net/pfvar.h>
+  #include <net/if_pflog.h>
+#endif
+}
+
 #include <cassert>
 #include <cstdlib>
 #include <cstring>
@@ -48,7 +58,7 @@
 #include "DwmPcap.hh"
 #include "DwmSvnTag.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.7/src/DwmPcap.cc 9479 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.8/src/DwmPcap.cc 9530 $");
 
 using namespace std;
 
@@ -123,6 +133,20 @@ namespace Dwm {
     return(rc);
   }
 
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool Pcap::SetDirection(pcap_direction_t direction)
+  {
+    bool  rc = false;
+    if (_pcap) {
+      if (pcap_setdirection(_pcap, direction) == 0) {
+        rc = true;
+      }
+    }
+    return rc;
+  }
+
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
@@ -225,6 +249,9 @@ namespace Dwm {
   }
   
   std::map<int,int>  Pcap::_dataLinkOffsets = {
+#if (defined(DLT_PFLOG) && defined(PFLOG_HDRLEN))
+    { DLT_PFLOG,   PFLOG_HDRLEN },
+#endif
     { DLT_NULL,     4 },
     { DLT_EN10MB,  14 },
     { DLT_IEEE802, 22 },
